--[[
Description: This plugin is part of the "Titan Panel [Currencies] Multi" addon. It shows your amount of Artifact Power.
Site: http://www.curse.com/addons/wow/titan-panel-currencies-multi
Author: Canettieri
Special Thanks to Eliote.
--]]

local ADDON_NAME, L = ...;
local ACE = LibStub("AceLocale-3.0"):GetLocale("Titan", true)
local version = GetAddOnMetadata(ADDON_NAME, "Version")
local ID = "TITAN_ARTFTM"
local ICON = "Interface\\Icons\\inv_scroll_05"
local artifactCount
local artifactTotalCount
local artifactMaximum
local artifactLevel
local artifactSpend
local weaponName
-----------------------------------------------
local function UpdateAll(self)
	if HasArtifactEquipped() then
	local itemID, altItemID, name, icon, totalXP, pointsSpent, quality, artifactAppearanceID, appearanceModID, itemAppearanceID, altItemAppearanceID, altOnTop = C_ArtifactUI.GetEquippedArtifactInfo();
  local numPointsAvailableToSpend, xp , xpForNextPoint = MainMenuBar_GetNumArtifactTraitsPurchasableFromXP(pointsSpent, totalXP);

	artifactCount = xp
	artifactTotalCount = totalXP
	artifactMaximum = xpForNextPoint
	artifactLevel = pointsSpent
	artifactSpend = numPointsAvailableToSpend
	weaponName = name
end

	TitanPanelButton_UpdateButton(self.registry.id)
end
-----------------------------------------------
local eventsTable = {
	ARTIFACT_UPDATE = UpdateAll, -- Atualização do Artefato
	BAG_UPDATE = UpdateAll, -- Atualização da Bolsa
	UNIT_DAMAGE = UpdateAll, -- Atualização da Arma
	ACTIVE_TALENT_GROUP_CHANGED = UpdateAll, -- Atualização da Árvore de Talentos
	PLAYER_ENTERING_WORLD = UpdateAll -- Jogador entra no Mundo
}
-----------------------------------------------
local function GetButtonText(self, id)
	if HasArtifactEquipped() then
		local XP = artifactCount
		local tolvl = artifactMaximum

		local weaponlvl = ""
		if artifactSpend == 0 or nil then
			weaponlvl = artifactLevel
		elseif
			artifactSpend > 0 then
				weaponlvl = artifactLevel.."|cFFFFFFFF-|cFFFF2e2e"..artifactSpend.."|r"
			end

			if not TitanGetVar(id, "SimpleText") then
				return L["ArticaftTitle"]..": ", "|cFFFFFFFF[|r|cFF198ae0"..weaponlvl.."|cFFFFFFFF]|r|cFF69FF69 "..XP.."|r|||cFFFFFFFF"..tolvl.." |cFFFF2e2e("..(artifactMaximum - artifactCount)..")"
			else
				return L["ArticaftTitle"]..": ", "|cFF69FF69"..XP.."|r|||cFFFFFFFF"..tolvl
			end

		else
			return L["noweapon"]
		end
	end
-----------------------------------------------
local function GetTooltipText(self, id)
	if HasArtifactEquipped() then
		local tooltiptext = "\r\r"..L["ArticaftLevel"]..artifactLevel.."|r\r"..L["ArticaftSpend"]..artifactSpend.."|r\r"..L["ArticaftXP"]..artifactCount.."|r\r"..L["ArticafttoMaximum"]..artifactMaximum.."|r\r"..L["ArticafttoLvL"]..(artifactMaximum - artifactCount)

		local hint = L["hint"]
		if TitanGetVar(id, "HideHint") then
			hint = ""
		end

		return hint..L["ArticaftName"].."|cFFe6cc80\r"..weaponName.."|r"..tooltiptext
	else
		return L["noweaponttp"]
	end
end
-----------------------------------------------
local function PrepareMenu(self, id)
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[id].menuText)
	TitanPanelRightClickMenu_AddToggleIcon(id)
	TitanPanelRightClickMenu_AddToggleLabelText(id)

	local info = UIDropDownMenu_CreateInfo();
	info.text = L["simpleText"];
	info.func = function() TitanToggleVar(id, "SimpleText"); TitanPanelButton_UpdateButton(id); end
	info.checked = TitanGetVar(id, "SimpleText");
	UIDropDownMenu_AddButton(info);

	local info = UIDropDownMenu_CreateInfo();
	info.text = L["hidehint"];
	info.func = function() TitanToggleVar(id, "HideHint"); TitanPanelButton_UpdateButton(id); end
	info.checked = TitanGetVar(id, "HideHint");
	UIDropDownMenu_AddButton(info);

	local info = UIDropDownMenu_CreateInfo();
	info.text = ACE["TITAN_CLOCK_MENU_DISPLAY_ON_RIGHT_SIDE"];
	info.func = function() TitanToggleVar(id, "DisplayOnRightSide"); TitanPanel_InitPanelButtons(id); end
	info.checked = TitanGetVar(id, "DisplayOnRightSide");
	UIDropDownMenu_AddButton(info);

	TitanPanelRightClickMenu_AddSpacer()
	TitanPanelRightClickMenu_AddCommand(ACE["TITAN_PANEL_MENU_HIDE"], id, TITAN_PANEL_MENU_FUNC_HIDE);
end
-----------------------------------------------
local function OnClick(self, button)
	if (button == "LeftButton") then
		SocketInventoryItem(16);
	end
end
-----------------------------------------------
L.Elib({
	id = ID,
	name = L["mLegion"].." Titan|cFF66b1ea "..L["ArticaftTitle"].."|r",
	tooltip = L["ArticaftTitle"],
	icon = ICON,
	category = "Information",
	version = version,
	onClick = OnClick,
	getButtonText = GetButtonText,
	eventsTable = eventsTable,
	getTooltipText = GetTooltipText,
	prepareMenu = PrepareMenu,
	savedVariables = {
		ShowIcon = 1,
		DisplayOnRightSide = false,
		ShowLabelText = false,
		SimpleText = false,
		HintText = false,
	}
})
